def main():
    from daedalus.daedalus import Daedalus
    Daedalus().main()
